guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

02/05: gnu: ruby-yard: Disable failing test.


From: Ben Woodcroft
Subject: 02/05: gnu: ruby-yard: Disable failing test.
Date: Mon, 11 Jan 2016 12:05:16 +0000

benwoodcroft pushed a commit to branch core-updates
in repository guix.

commit 048036aee522d6a03436bf530d139ec26d8a438e
Author: Ben Woodcroft <address@hidden>
Date:   Wed Jan 6 21:57:44 2016 +1000

    gnu: ruby-yard: Disable failing test.
    
    * gnu/packages/ruby.scm (ruby-yard)[arguments]: Disable test which fails on
    Ruby 2.3.0.
---
 gnu/packages/ruby.scm |   14 +++++++++++---
 1 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/ruby.scm b/gnu/packages/ruby.scm
index d3e6dbc..61c6c3c 100644
--- a/gnu/packages/ruby.scm
+++ b/gnu/packages/ruby.scm
@@ -2776,9 +2776,17 @@ features such as filtering and fine grained logging.")
      `(#:test-target "specs"
        #:phases
        (modify-phases %standard-phases
-         (add-before 'check 'set-HOME
-          ;; $HOME needs to be set to somewhere writeable for tests to run
-          (lambda _ (setenv "HOME" "/tmp") #t)))))
+         (add-before 'check 'set-HOME-and-disable-failing-test
+           (lambda _
+             ;; $HOME needs to be set to somewhere writeable for tests to run
+             (setenv "HOME" "/tmp")
+             ;; Disable tests which fails on Ruby 2.3.  See
+             ;; https://github.com/lsegal/yard/issues/927
+             (substitute* "spec/parser/ruby/ruby_parser_spec.rb"
+               (("comment.type.should == :comment") "")
+               (("comment.docstring_hash_flag.should be_true") "")
+               (("comment.docstring.strip.should == .*") ""))
+             #t)))))
     (native-inputs
      `(("ruby-rspec" ,ruby-rspec-2)
        ("ruby-rack" ,ruby-rack)))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]